@@ -101,7 +101,13 @@ void ListParamWidget::slotRefresh()
         // Create thumbnails
         if (pCore->getCurrentFrameSize().width() > 1000) {
             // HD project
-            values = MainWindow::m_lumaFiles.value(QStringLiteral("HD"));
+            values = MainWindow::m_lumaFiles.value(QStringLiteral("16_9"));
+        } else if (pCore->getCurrentFrameSize().height() > 1000) {
+            values = MainWindow::m_lumaFiles.value(QStringLiteral("9_16"));
+        } else if (pCore->getCurrentFrameSize().height() == pCore->getCurrentFrameSize().width()) {
+            values = MainWindow::m_lumaFiles.value(QStringLiteral("square"));
+        } else if (pCore->getCurrentFrameSize().height() == 480) {
+            values = MainWindow::m_lumaFiles.value(QStringLiteral("NTSC"));
         } else {
             values = MainWindow::m_lumaFiles.value(QStringLiteral("PAL"));
         }
