@@ -33,16 +33,15 @@ public:
         Calculates a histogram display from the input image.
         components are OR-ed HistogramGenerator::Components flags and decide with components (Y, R, G, B) to paint.
         unscaled = true leaves the width at 256 if the widget is wider (to avoid scaling). */
-    QImage calculateHistogram(const QSize &paradeSize, const QImage &image, const int &components, const HistogramGenerator::Rec rec,
-                              bool unscaled, uint accelFactor = 1) const;
+    QImage calculateHistogram(const QSize &paradeSize, const QImage &image, const int &components, const HistogramGenerator::Rec rec, bool unscaled,
+                              uint accelFactor = 1) const;
 
     QImage drawComponent(const int *y, const QSize &size, const float &scaling, const QColor &color, bool unscaled, uint max) const;
 
-    void drawComponentFull(QPainter *davinci, const int *y, const float &scaling, const QRect &rect,
-                           const QColor &color, int textSpace, bool unscaled, uint max) const;
+    void drawComponentFull(QPainter *davinci, const int *y, const float &scaling, const QRect &rect, const QColor &color, int textSpace, bool unscaled,
+                           uint max) const;
 
     enum Components { ComponentY = 1 << 0, ComponentR = 1 << 1, ComponentG = 1 << 2, ComponentB = 1 << 3, ComponentSum = 1 << 4 };
-
 };
 
 #endif // HISTOGRAMGENERATOR_H
