@@ -314,7 +314,7 @@ bool TimelineFunctions::extractZone(const std::shared_ptr<TimelineItemModel> &ti
     std::function<bool(void)> redo = []() { return true; };
     bool result = true;
     result = breakAffectedGroups(timeline, tracks, zone, undo, redo);
-    
+
     for (int &trackId : tracks) {
         if (timeline->getTrackById_const(trackId)->isLocked()) {
             continue;
@@ -337,15 +337,27 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
     bool result = true;
     QVector<int> affectedTracks;
     auto it = timeline->m_allTracks.cbegin();
-    while (it != timeline->m_allTracks.cend()) {
-        int target_track = (*it)->getId();
-        if (timeline->getTrackById_const(target_track)->shouldReceiveTimelineOp()) {
-            affectedTracks << target_track;
-        } else if (trackIds.contains(target_track)) {
-            // Track is marked as target but not active, remove it
-            trackIds.removeAll(target_track);
+    if (!useTargets && overwrite) {
+        // Timeline drop in overwrite mode
+        for (int target_track : trackIds) {
+            if (!timeline->getTrackById_const(target_track)->isLocked()) {
+                affectedTracks << target_track;
+            }
         }
-        ++it;
+    } else {
+        while (it != timeline->m_allTracks.cend()) {
+            int target_track = (*it)->getId();
+            if (!useTargets || timeline->getTrackById_const(target_track)->shouldReceiveTimelineOp()) {
+                affectedTracks << target_track;
+            } else if (trackIds.contains(target_track)) {
+                // Track is marked as target but not active, remove it
+                trackIds.removeAll(target_track);
+            }
+            ++it;
+        }
+    }
+    if (affectedTracks.isEmpty()) {
+        return false;
     }
     result = breakAffectedGroups(timeline, affectedTracks, QPoint(insertFrame, insertFrame + (zone.y() - zone.x())), undo, redo);
     if (overwrite) {
@@ -368,12 +380,20 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
         }
         result = result && TimelineFunctions::requestInsertSpace(timeline, QPoint(insertFrame, insertFrame + (zone.y() - zone.x())), undo, redo, affectedTracks);
     }
-
+    bool clipInserted = false;
     if (result) {
         if (!trackIds.isEmpty()) {
             int newId = -1;
-            QString binClipId = QString("%1/%2/%3").arg(binId).arg(zone.x()).arg(zone.y() - 1);
+            QString binClipId;
+            if (binId.contains(QLatin1Char('/'))) {
+                binClipId = QString("%1/%2/%3").arg(binId.section(QLatin1Char('/'), 0, 0)).arg(zone.x()).arg(zone.y() - 1);
+            } else {
+                binClipId = QString("%1/%2/%3").arg(binId).arg(zone.x()).arg(zone.y() - 1);
+            }
             result = timeline->requestClipInsertion(binClipId, trackIds.first(), insertFrame, newId, true, true, useTargets, undo, redo, affectedTracks);
+            if (result) {
+                clipInserted = true;
+            }
         }
         if (result) {
             pCore->pushUndo(undo, redo, overwrite ? i18n("Overwrite zone") : i18n("Insert zone"));
@@ -383,7 +403,7 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
         qDebug() << "// REQUESTING SPACE FAILED";
         undo();
     }
-    return result;
+    return clipInserted;
 }
 
 bool TimelineFunctions::liftZone(const std::shared_ptr<TimelineItemModel> &timeline, int trackId, QPoint zone, Fun &undo, Fun &redo)
@@ -417,7 +437,6 @@ bool TimelineFunctions::liftZone(const std::shared_ptr<TimelineItemModel> &timel
 bool TimelineFunctions::removeSpace(const std::shared_ptr<TimelineItemModel> &timeline, int trackId, QPoint zone, Fun &undo, Fun &redo, QVector<int> allowedTracks)
 {
     Q_UNUSED(trackId)
-
     std::unordered_set<int> clips;
     auto it = timeline->m_allTracks.cbegin();
     while (it != timeline->m_allTracks.cend()) {
@@ -428,6 +447,10 @@ bool TimelineFunctions::removeSpace(const std::shared_ptr<TimelineItemModel> &ti
         }
         ++it;
     }
+    if (clips.size() == 0) {
+        // TODO: inform user no change will be performed
+        return true;
+    }
     bool result = false;
     timeline->requestSetSelection(clips);
     int itemId = *clips.begin();
@@ -1398,6 +1421,12 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
             in = 0;
             timeline->m_allClips[newId]->m_producer->set("length", out + 1);
         }
+        if (speed < 0) {
+            // on negative speed clips, in/out are inverted
+            int length = out - in;
+            in = timeline->m_allClips[newId]->getMaxDuration() - out;
+            out = in + length;
+        }
         timeline->m_allClips[newId]->setInOut(in, out);
         int targetId = prod.attribute(QStringLiteral("id")).toInt();
         correspondingIds[targetId] = newId;
