@@ -76,6 +76,8 @@ TimelineController::TimelineController(QObject *parent)
     m_disablePreview = pCore->currentDoc()->getAction(QStringLiteral("disable_preview"));
     connect(m_disablePreview, &QAction::triggered, this, &TimelineController::disablePreview);
     connect(this, &TimelineController::selectionChanged, this, &TimelineController::updateClipActions);
+    connect(this, &TimelineController::videoTargetChanged, this, &TimelineController::updateVideoTarget);
+    connect(this, &TimelineController::audioTargetChanged, this, &TimelineController::updateAudioTarget);
     m_disablePreview->setEnabled(false);
     connect(pCore.get(), &Core::finalizeRecording, this, &TimelineController::finishRecording);
 }
@@ -107,12 +109,16 @@ void TimelineController::setModel(std::shared_ptr<TimelineItemModel> model)
 
 void TimelineController::setTargetTracks(QPair<int, int> targets)
 {
-    //setVideoTarget(targets.first >= 0 && targets.first < m_model->getTracksCount() ? m_model->getTrackIndexFromPosition(targets.first) : -1);
-    //setAudioTarget(targets.second >= 0 && targets.second < m_model->getTracksCount() ? m_model->getTrackIndexFromPosition(targets.second) : -1);
     m_hasVideoTarget = targets.first >= 0;
     m_hasAudioTarget = targets.second >= 0;
-    setVideoTarget(targets.first);
-    setAudioTarget(targets.second);
+    emit hasAudioTargetChanged();
+    emit hasVideoTargetChanged();
+    if (m_videoTargetActive) {
+        setVideoTarget(m_hasVideoTarget && (m_lastVideoTarget > -1) ? m_lastVideoTarget : targets.first);
+    }
+    if (m_audioTargetActive) {
+        setAudioTarget(m_hasAudioTarget && (m_lastAudioTarget > -1) ? m_lastAudioTarget : targets.second);
+    }
 }
 
 std::shared_ptr<TimelineItemModel> TimelineController::getModel() const
@@ -572,6 +578,14 @@ void TimelineController::deleteTrack(int tid)
         if (m_model->m_videoTarget == selectedTrackIx) {
             setVideoTarget(-1);
         }
+        if (m_lastAudioTarget == selectedTrackIx) {
+            m_lastAudioTarget = -1;
+            emit lastAudioTargetChanged();
+        }
+        if (m_lastVideoTarget == selectedTrackIx) {
+            m_lastVideoTarget = -1;
+            emit lastVideoTargetChanged();
+        }
         m_model->requestTrackDeletion(selectedTrackIx);
         m_model->buildTrackCompositing(true);
         if (m_activeTrack == -1) {
@@ -915,18 +929,27 @@ void TimelineController::setPosition(int position)
 
 void TimelineController::setAudioTarget(int track)
 {
+    if (track > -1 && !m_model->isTrack(track) || !m_hasAudioTarget) {
+        return;
+    }
     m_model->m_audioTarget = track;
     emit audioTargetChanged();
 }
 
 void TimelineController::setVideoTarget(int track)
 {
+    if (track > -1 && !m_model->isTrack(track) || !m_hasVideoTarget) {
+        return;
+    }
     m_model->m_videoTarget = track;
     emit videoTargetChanged();
 }
 
 void TimelineController::setActiveTrack(int track)
 {
+    if (track > -1 && !m_model->isTrack(track)) {
+        return;
+    }
     m_activeTrack = track;
     emit activeTrackChanged();
 }
@@ -1488,6 +1511,16 @@ void TimelineController::invalidateItem(int cid)
     m_timelinePreview->invalidatePreview(start, end);
 }
 
+void TimelineController::invalidateTrack(int tid)
+{
+    if (!m_timelinePreview || !m_model->isTrack(tid)) {
+        return;
+    }
+    for (auto clp : m_model->getTrackById_const(tid)->m_allClips) {
+        invalidateItem(clp.first);
+    }
+}
+
 void TimelineController::invalidateZone(int in, int out)
 {
     if (!m_timelinePreview) {
@@ -1522,7 +1555,6 @@ void TimelineController::changeItemSpeed(int clipId, double speed)
             minSpeed = std::max(minSpeed, minSpeed2);
             maxSpeed = std::min(maxSpeed, maxSpeed2);
         }
-        // speed = QInputDialog::getDouble(QApplication::activeWindow(), i18n("Clip Speed"), i18n("Percentage"), speed, minSpeed, maxSpeed, 2, &ok);
         QScopedPointer<SpeedDialog> d(new SpeedDialog(QApplication::activeWindow(), std::abs(speed), minSpeed, maxSpeed, speed < 0));
         if (d->exec() != QDialog::Accepted) {
             return;
@@ -1655,7 +1687,7 @@ bool TimelineController::insertClipZone(const QString &binId, int tid, int posit
     if (aTrack > -1) {
         target_tracks << aTrack;
     }
-    return TimelineFunctions::insertZone(m_model, target_tracks, binId, position, QPoint(in, out), m_model->m_editMode == TimelineMode::OverwriteEdit, false);
+    return TimelineFunctions::insertZone(m_model, target_tracks, binId, position, QPoint(in, out + 1), m_model->m_editMode == TimelineMode::OverwriteEdit, false);
 }
 
 int TimelineController::insertZone(const QString &binId, QPoint zone, bool overwrite)
@@ -2207,7 +2239,10 @@ void TimelineController::grabCurrent()
 int TimelineController::getItemMovingTrack(int itemId) const
 {
     if (m_model->isClip(itemId)) {
-        int trackId = m_model->m_allClips[itemId]->getFakeTrackId();
+        int trackId = -1;
+        if (m_model->m_editMode != TimelineMode::NormalEdit) {
+            trackId = m_model->m_allClips[itemId]->getFakeTrackId();
+        }
         return trackId < 0 ? m_model->m_allClips[itemId]->getCurrentTrackId() : trackId;
     }
     return m_model->m_allCompositions[itemId]->getCurrentTrackId();
@@ -2252,6 +2287,10 @@ bool TimelineController::endFakeMove(int clipId, int position, bool updateView,
     }
     res = res && m_model->getTrackById(trackId)->requestClipInsertion(clipId, position, updateView, invalidateTimeline, undo, redo);
     if (res) {
+        // Terminate fake move
+        if (m_model->isClip(clipId)) {
+            m_model->m_allClips[clipId]->setFakeTrackId(-1);
+        }
         if (logUndo) {
             pCore->pushUndo(undo, redo, i18n("Move item"));
         }
@@ -2268,6 +2307,10 @@ bool TimelineController::endFakeGroupMove(int clipId, int groupId, int delta_tra
     std::function<bool(void)> redo = []() { return true; };
     bool res = endFakeGroupMove(clipId, groupId, delta_track, delta_pos, updateView, logUndo, undo, redo);
     if (res && logUndo) {
+        // Terminate fake move
+        if (m_model->isClip(clipId)) {
+            m_model->m_allClips[clipId]->setFakeTrackId(-1);
+        }
         pCore->pushUndo(undo, redo, i18n("Move group"));
     }
     return res;
@@ -2551,3 +2594,26 @@ void TimelineController::finishRecording(const QString &recordedFile)
         pCore->pushUndo(undo, redo, i18n("Record audio"));
     }
 }
+
+
+void TimelineController::updateVideoTarget()
+{
+    if (videoTarget() > -1) {
+        m_lastVideoTarget = videoTarget();
+        m_videoTargetActive = true;
+        emit lastVideoTargetChanged();
+    } else {
+        m_videoTargetActive = false;
+    }
+}
+
+void TimelineController::updateAudioTarget()
+{
+    if (audioTarget() > -1) {
+        m_lastAudioTarget = audioTarget();
+        m_audioTargetActive = true;
+        emit lastAudioTargetChanged();
+    } else {
+        m_audioTargetActive = false;
+    }
+}
