@@ -67,8 +67,12 @@ class TimelineController : public QObject
     Q_PROPERTY(int activeTrack READ activeTrack WRITE setActiveTrack NOTIFY activeTrackChanged)
     Q_PROPERTY(int audioTarget READ audioTarget WRITE setAudioTarget NOTIFY audioTargetChanged)
     Q_PROPERTY(int videoTarget READ videoTarget WRITE setVideoTarget NOTIFY videoTargetChanged)
-    Q_PROPERTY(bool hasAudioTarget READ hasAudioTarget)
-    Q_PROPERTY(bool hasVideoTarget READ hasVideoTarget)
+    
+    Q_PROPERTY(int lastAudioTarget MEMBER m_lastAudioTarget NOTIFY lastAudioTargetChanged)
+    Q_PROPERTY(int lastVideoTarget MEMBER m_lastVideoTarget NOTIFY lastVideoTargetChanged)
+    
+    Q_PROPERTY(bool hasAudioTarget READ hasAudioTarget NOTIFY hasAudioTargetChanged)
+    Q_PROPERTY(bool hasVideoTarget READ hasVideoTarget NOTIFY hasVideoTargetChanged)
     Q_PROPERTY(QColor videoColor READ videoColor NOTIFY colorsChanged)
     Q_PROPERTY(QColor audioColor READ audioColor NOTIFY colorsChanged)
     Q_PROPERTY(QColor lockedColor READ lockedColor NOTIFY colorsChanged)
@@ -472,6 +476,7 @@ public slots:
     /** @brief Dis / enable timeline preview. */
     void disablePreview(bool disable);
     void invalidateItem(int cid);
+    void invalidateTrack(int tid);
     void invalidateZone(int in, int out);
     void checkDuration();
     /** @brief Dis / enable multi track view. */
@@ -483,6 +488,8 @@ public slots:
 
 private slots:
     void updateClipActions();
+    void updateVideoTarget();
+    void updateAudioTarget();
 
 public:
     /** @brief a list of actions that have to be enabled/disabled depending on the timeline selection */
@@ -501,6 +508,10 @@ private:
     int m_audioRef;
     bool m_hasAudioTarget {false};
     bool m_hasVideoTarget {false};
+    int m_lastVideoTarget {-1};
+    int m_lastAudioTarget {-1};
+    bool m_videoTargetActive {true};
+    bool m_audioTargetActive {true};
     QPair<int, int> m_recordStart;
     int m_recordTrack;
     QPoint m_zone;
@@ -527,6 +538,10 @@ signals:
     void seekPositionChanged();
     void audioTargetChanged();
     void videoTargetChanged();
+    void hasAudioTargetChanged();
+    void hasVideoTargetChanged();
+    void lastAudioTargetChanged();
+    void lastVideoTargetChanged();
     void activeTrackChanged();
     void colorsChanged();
     void showThumbnailsChanged();
